
![Tests Status](https://github.com/aetperf/edsger/actions/workflows/tests.yml/badge.svg?branch=release)

# Edsger


*Graph algorithms in Cython*


Welcome to our Python library for graph algorithms, built with the power of Cython. So far, the library only includes Dijkstra's algorithm but we should add a range of common path algorithms soon. It is also open-source and easy to integrate with other Python libraries. To get started, simply install the library using pip, and import it into your Python project.
